# Network

::: flyvis.network.network.Network

## Stimulus

Stimuli must implement the `StimulusProtocol` to be compatible with
`flyvis.network.network.Network`.

::: flyvis.network.stimulus.StimulusProtocol

::: flyvis.network.stimulus.Stimulus

::: flyvis.network.stimulus.register_stimulus

::: flyvis.network.stimulus.init_stimulus

## Dynamics

::: flyvis.network.dynamics.NetworkDynamics

::: flyvis.network.dynamics.PPNeuronIGRSynapses

## Initialization

::: flyvis.network.initialization
